<?php

/**
 * Plugin Name: BWL Pro Voting Manager
 * Plugin URI: https://1.envato.market/bpvm-wp
 * Description: The BWL Pro Voting Manager offers a convenient feature enabling you to integrate a custom voting system into individual posts automatically. The feedback option effectively gathers user feedback, facilitating post-improvement and enhancing user engagement.
 * Author: Mahbub Alam Khan
 * Version: 1.4.0
 * WP Requires at least: 6.0+
 * Author URI:     https://codecanyon.net/user/xenioushk
 * Text Domain: bwl-pro-voting-manager
 * Domain Path: /lang/
 * 
 * 
 * @package BWL Pro Voting Manager
 * @author Mahbub Alam Khan
 * @license GPL-2.0+
 * @link https://codecanyon.net/user/xenioushk
 * @copyright 2023 BlueWindLab
 * 
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

class BWL_Pro_Voting_Manager
{

    public function __construct()
    {

        /*--- PLUGIN COMMON CONSTANTS ------*/
        define("BWL_PVM_PLUGIN_VERSION", '1.4.0');
        define("BWL_PVM_PLUGIN_TITLE", 'BWL Pro Voting Manager');
        define("BWL_PVM_PLUGIN_ROOT", "bwl-pro-voting-manager");
        define("BWL_PVM_PLUGIN_DIR", plugins_url() . '/bwl-pro-voting-manager/');
        define("BWL_PVM_PLUGIN_ROOT_FILE", 'bwl-pro-voting-manager.php'); // use for the meta info.
        define("PVM_DB_TABLE_UPDATE", 'pvm_db_update_111');
        define("BWL_PVM_PLUGIN_UPDATER_SLUG", plugin_basename(__FILE__)); // Required for plugin autoupdate.
        define("BWL_PVM_PLUGIN_PATH", __DIR__);

        define("BWL_PVM_INSTALLATION_TAG", "bpvm_installation_" . str_replace('.', '_', BWL_PVM_PLUGIN_VERSION));
        define("BPVM_CC_ID", "7616885"); // Plugin codecanyon Id.
        define("BPVM_CC_URL", "https://1.envato.market/bpvm-wp"); // Plugin codecanyon URL.
        define("BPVM_SUPPORT_URL", "https://codecanyon.net/item/bwl-pro-voting-manager/7616885/support/contact"); // plugin support url.
        define("BPVM_YOUTUBE_PLAYLIST", "https://www.youtube.com/playlist?list=PLxYTuQlgnCLqNxc2N7XUDYllIJjJB_-tU"); // YouTube link
        define("BPVM_VERIFIED", get_option('bpvm_purchase_verified')); // purchase verification status.

        // Database Constants.

        global $wpdb;

        define("BPVM_VOTE_DATA_TABLE", $wpdb->prefix . "bpvm_data"); // Data table that store all the voting data.
        define("BPVM_SUMMARY_DATA_TABLE", $wpdb->prefix . "bpvm_summary"); // Summary table that stores all the likes and dislikes vote group by date.        

        // Call Immediatly Initialized.
        $this->includeFiles();

        //Load Required Frontend and Admin Scripts.

        add_action('wp_enqueue_scripts', [$this, 'enqueueFrontendScripts']);
        add_action('admin_enqueue_scripts', [$this, 'enqueueAdminScripts']);
        add_action('plugins_loaded', [$this, 'loadTranslationFile']);
    }


    // ALTER COLUMN FOR IP ADDRESS.

    function includeFiles()
    {

        add_image_size('pvm-post-thumb', 32, 32, true);

        require_once(BWL_PVM_PLUGIN_PATH . '/includes/pvm-helper-functions.php');

        // Include Database Settings Table.

        require_once(BWL_PVM_PLUGIN_PATH . '/includes/db/BpvmDbSettings.php');

        require_once(BWL_PVM_PLUGIN_PATH . '/includes/pvm-interface.php');

        // Save dislike feedback data.
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/pvm-handle-dislike-feedback.php');

        // Voting count files.
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/user-voting-info.php');
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/single-vote-checker.php');
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/category-wise-vote-checker.php');
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/logged-in-vote-checker.php');
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/pvm-vote-status-checker.php');
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/pvm-vote-counter.php');
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/pvm-custom-theme.php');

        // Integrate shortcode files.

        require_once(BWL_PVM_PLUGIN_PATH . '/includes/shortcodes/pvm-shortcodes.php');
        require_once(BWL_PVM_PLUGIN_PATH . '/includes/shortcodes/pvm-share-shortcode.php');

        if (is_admin()) {

            // Plugin Metainfo.
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/metainfo/BpvmMetaInfo.php');

            // TinyMce.
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/tinymce/bpvm_tiny_mce_config.php');

            // CMB & Columns.
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/pvm-custom-column.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/pvm-custom-meta-box.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/pvm-quick-edit.php');

            // Options panel and purchase verification.
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/option-panel/options-panel-menu.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/option-panel/plugin-voting-report.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/option-panel/options-panel-settings.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/option-panel/plugin-purchase-verify.php');

            // Auto Updater Scripts.
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/autoupdater/WpAutoUpdater.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/autoupdater/updater.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/autoupdater/installer.php');
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/autoupdater/pvm-update-notifier.php');

            // Admin Notice.
            require_once(BWL_PVM_PLUGIN_PATH . '/includes/admin/noticebox/BpvmAdminNotice.php');
        }
    }

    public function enqueueFrontendScripts()
    {

        $pvm_data = get_option('bwl_pvm_options');

        // Load Font-awesome.

        if (
            !isset($pvm_data['pvm_fontawesome_status']) ||
            $pvm_data['pvm_fontawesome_status'] == 1
        ) {
            wp_enqueue_style('font-awesome', plugins_url('libs/font-awesome/font-awesome.min.css', __FILE__));
            wp_enqueue_style('font-shims-awesome', plugins_url('libs/font-awesome/v4-shims.min.css', __FILE__));
        }

        wp_enqueue_style('bpvm-frontend', plugins_url('assets/styles/frontend.css', __FILE__), [], BWL_PVM_PLUGIN_VERSION);

        // Load RTL Support Styling.

        if (is_rtl()) {

            wp_enqueue_style('bpvm-frontend-rtl', plugins_url('assets/styles/frontend_rtl.css', __FILE__), [], BWL_PVM_PLUGIN_VERSION);
        }

        /* --- Load Custom Scripts ---*/

        wp_register_script('jquery-tipsy', plugins_url('libs/jquery.tipsy/scripts/jquery.tipsy.js', __FILE__), ['jquery'], BWL_PVM_PLUGIN_VERSION, TRUE);
        wp_enqueue_script('bpvm-frontend', plugins_url('assets/scripts/frontend.js', __FILE__), ['jquery', 'jquery-tipsy'], BWL_PVM_PLUGIN_VERSION, TRUE);

        wp_localize_script(
            'bpvm-frontend',
            'bpvmFrontendData',
            [
                'pvm_wait_msg' => esc_html__("Please Wait .....", "bwl-pro-voting-manager")
            ]
        );
    }

    public function enqueueAdminScripts()
    {

        wp_enqueue_style('bwl-pvm-shortcode-editor', plugins_url('libs/tinymce/styles/bwl_pvm_editor.css', __FILE__), [], BWL_PVM_PLUGIN_VERSION);
        wp_enqueue_style('bwl-pvm-multiple-select', plugins_url('libs/multiple-select/styles/multiple-select.css', __FILE__), [], BWL_PVM_PLUGIN_VERSION);

        wp_register_style('bwl-pvm-jquery-ui-style', plugins_url('libs/jqueryui/flick/jquery-ui-1.9.0.custom.min.css', __FILE__), [], BWL_PVM_PLUGIN_VERSION);
        // wp_register_style('bwl-pvm-cmb-styles', plugins_url('css/pvm-cmb-styles.css', __FILE__), ['bwl-pvm-jquery-ui-style']);

        wp_register_style('bwl-pvm-datatables-style', plugins_url('libs/jquery.dataTables/styles/jquery.dataTables.css', __FILE__), ['bwl-pvm-jquery-ui-style'], BWL_PVM_PLUGIN_VERSION);
        // wp_enqueue_style('bwl-pvm-cmb-styles');

        wp_enqueue_style('bpvm-admin', plugins_url('assets/styles/admin.css', __FILE__), ['bwl-pvm-jquery-ui-style'], BWL_PVM_PLUGIN_VERSION);

        /*--- Load Custom Scripts ------*/

        // Register Data Table & It's required codes.
        wp_register_script('bpvm-datatable-script', plugins_url('libs/jquery.dataTables/scripts/jquery.dataTables.min.js', __FILE__), ['jquery'], BWL_PVM_PLUGIN_VERSION, TRUE);
        // wp_register_script('bpvm-admin-voting-report-script', plugins_url('js/pvm-admin-voting-report.js', __FILE__), ['jquery', 'jquery-ui-core', 'jquery-ui-datepicker', 'jquery-ui-dialog', 'bpvm-datatable-script'], BWL_PVM_PLUGIN_VERSION, TRUE);

        wp_enqueue_script('bwl-pvm-multiple-select', plugins_url('libs/multiple-select/scripts/jquery.multiple.select.js', __FILE__), ['jquery'], BWL_PVM_PLUGIN_VERSION, TRUE);


        wp_enqueue_script('bpvm-admin', plugins_url('assets/scripts/admin.js', __FILE__), ['jquery', 'jquery-ui-core', 'jquery-ui-datepicker', 'jquery-ui-dialog', 'jquery-ui-draggable', 'jquery-ui-droppable'], BWL_PVM_PLUGIN_VERSION, TRUE);
        wp_localize_script(
            'bpvm-admin',
            'bpvmAdminData',
            [
                'bpvm_text_loading' => esc_html__("Loading .....", "bwl-pro-voting-manager"),
                'bpvm_pvc_required_msg' => esc_html__("Purchase code is required!", "bwl-pro-voting-manager"),
                'bpvm_pvc_success_msg' => esc_html__("Purchase code verified. Reloading window in 3 seconds.", "bwl-pro-voting-manager"),
                'bpvm_pvc_failed_msg' => esc_html__("Unable to verify purchase code. Please try again or contact support team.", "bwl-pro-voting-manager"),
                'bpvm_pvc_remove_msg' => esc_html__("Are you sure to remove the license info?", "bwl-pro-voting-manager"),
                'bpvm_pvc_removed_msg' => esc_html__("Purchase code removed. Reloading window in 3 seconds.", "bwl-pro-voting-manager"),
                'bpvm_confirm_remove_msg' => esc_html__("Are you sure to remove data?", "bwl-pro-voting-manager"),
                'product_id' => BPVM_CC_ID,
                'installation' => get_option(BWL_PVM_INSTALLATION_TAG),
                'bpvm_dir' => BWL_PVM_PLUGIN_DIR // for tinymce editor.
            ]
        );
    }

    public function loadTranslationFile()
    {
        /* ---  TRANSLATION FILE ---*/
        load_plugin_textdomain("bwl-pro-voting-manager", FALSE, dirname(plugin_basename(__FILE__)) . '/lang/');
    }
}

/* --- Initialization ---*/

function initBwlProVotingManager()
{
    new BWL_Pro_Voting_Manager();
}

add_action('init', 'initBwlProVotingManager');

require_once(__DIR__ . '/includes/widgets/pvm-widget.php');
