<?php

class BpvmDbSettings
{

  public function __construct()
  {

    $this->bpvm_create_custom_table();

    //Update vote data
    //@Since: version 1.1.2
    $this->pvm_upgrade_plugin_data();

    // @introduced in version 1.1.1
    $this->bpvm_version_manager(BWL_PVM_PLUGIN_VERSION);
  }

  // We are going to update summary table data.
  // Which is very important.
  // Fixed in version 1.1.2

  public function pvm_upgrade_plugin_data()
  {

    // First we need to check if the patch already applied or not.
    $pvm_upgrade_plugin_data_status = get_option('pvm_patch_112');

    // If its return 1 then we assume patch already installed.
    if ($pvm_upgrade_plugin_data_status != 1) {

      // Get available custom Post Types installed in to system.
      $pvm_available_post_types = bpvm_clean_custom_post_types();

      global $wpdb;

      // We need this two custom tables.

      $bpvm_voting_summary_table = $wpdb->prefix . "bpvm_summary"; // daily summary. 
      $bpvm_voting_details_table = $wpdb->prefix . "bpvm_data"; // Details Data.

      // Then create a loop for each custom post type.

      foreach ($pvm_available_post_types as $post_type_key => $post_type_name) {


        //Step 01; First we need to get summary table data. We pick postid, vote date and total votes from that table.
        // Where clauses are: post type and vote type.
        // st = summary table.
        // dt = data table.

        /*--- Like Section ------*/

        $st_custom_like_query = "SELECT postid, vote_date, total_votes From " . $bpvm_voting_summary_table . " WHERE " . $bpvm_voting_summary_table . ".vote_type=1 AND wp_bpvm_summary.post_type='" . $post_type_name . "' order by vote_date DESC";
        $st_custom_like_query_results = $wpdb->get_results($st_custom_like_query, ARRAY_A);

        // If no data available in to summary table then we do not need to go inside and check in to data table.

        if (count($st_custom_like_query_results) > 0) {

          foreach ($st_custom_like_query_results as $result) {

            $postid = $result['postid']; // get post id.
            $post_type = $post_type_name; // get post type.
            $vote_type = 1; // get vote type.
            $total_votes = $result['total_votes']; // get total votes and we will match the total votes with data table total votes.
            $vote_date = $result['vote_date']; // vote date

            // Now update each post total vote data

            $dt_custom_like_query = "SELECT SUM(votes) as DTV From `" . $bpvm_voting_details_table . "` WHERE vote_type=1 AND DATE(vote_date)='" . $vote_date . "' AND postid=" . $postid . " AND post_type = '" . $post_type_key . "'";
            $dt_custom_like_query_results = $wpdb->get_results($dt_custom_like_query, ARRAY_A);

            // Checking if array is empty or not.

            if (count($dt_custom_like_query_results) > 0) {

              // There we are going to do another matching.

              if ($total_votes != $dt_custom_like_query_results[0]['DTV']) {
                // We will update summary table data by $dt_custom_like_query_results.
                $st_like_update_args = [
                  'postid' => $postid,
                  'post_type' => $post_type,
                  'vote_type' => $vote_type, // like=1, dislike=2
                  'vote_date' => $vote_date
                ];

                $wpdb->update(
                  $bpvm_voting_summary_table,
                  [
                    'total_votes' => $dt_custom_like_query_results[0]['DTV']
                  ], // Data – array of data to update as column->value pairs
                  $st_like_update_args,
                  ['%d'], // Data Format 
                  ['%d', '%s', '%d', '%s'] // Where Format 
                );
              }
            }
          }
        }

        wp_reset_query();

        /*--- Dislike Section ------*/

        $st_custom_dislike_query = "SELECT postid, vote_date, total_votes From " . $bpvm_voting_summary_table . " WHERE " . $bpvm_voting_summary_table . ".vote_type=2 AND wp_bpvm_summary.post_type='" . $post_type_name . "' order by vote_date DESC";
        $st_custom_dislike_query_results = $wpdb->get_results($st_custom_dislike_query, ARRAY_A);

        // If no data available in to summary table then we do not need to go inside and check in to data table.

        if (count($st_custom_dislike_query_results) > 0) {


          foreach ($st_custom_dislike_query_results as $result) {

            $postid = $result['postid']; // get post id.
            $post_type = $post_type_name; // get post type.
            $vote_type = 2; // get vote type.
            $total_votes = $result['total_votes']; // get total votes and we will match the total votes with data table total votes.
            $vote_date = $result['vote_date']; // vote date

            // Now update each post total vote data

            $dt_custom_dislike_query = "SELECT SUM(votes) as DTV From `" . $bpvm_voting_details_table . "` WHERE vote_type=2 AND DATE(vote_date)='" . $vote_date . "' AND postid=" . $postid . " AND post_type = '" . $post_type_key . "'";
            $dt_custom_dislike_query_results = $wpdb->get_results($dt_custom_dislike_query, ARRAY_A);

            // Checking if array is empty or not.

            if (count($dt_custom_dislike_query_results) > 0) {

              // There we are going to do another matching.

              if ($total_votes != $dt_custom_dislike_query_results[0]['DTV']) {
                // We will update summary table data by $dt_custom_dislike_query_results.
                $st_dislike_update_args = [
                  'postid' => $postid,
                  'post_type' => $post_type,
                  'vote_type' => $vote_type, // like=1, dislike=2
                  'vote_date' => $vote_date
                ];

                $wpdb->update(
                  $bpvm_voting_summary_table,
                  [
                    'total_votes' => $dt_custom_dislike_query_results[0]['DTV']
                  ], // Data – array of data to update as column->value pairs
                  $st_dislike_update_args,
                  ['%d'], // Data Format 
                  ['%d', '%s', '%d', '%s'] // Where Format 
                );
              }
            }
          }
        }

        wp_reset_query();
      }

      // Update patch status.
      update_option('pvm_patch_112', 1);
    }
  }

  public function bpvm_version_manager($latest_version)
  {

    $current_version = get_option('bwl_pvm_plugin_version');

    if ($current_version == "") {

      update_option('bwl_pvm_plugin_version', $latest_version);
    } elseif ($current_version != $latest_version) {

      update_option('bwl_pvm_plugin_version', $latest_version);
    } else {
      // Do nothing!
    }
  }

  //Fixing Table Prefix Name.

  //@Custom Table For Count Votes.
  //@Introduced in version: 1.1.0

  public function bpvm_create_custom_table()
  {

    global $wpdb;
    $bpvm_voting_data_table = $wpdb->prefix . "bpvm_data"; // for deatils. each day info.
    $bpvm_voting_summary_table = $wpdb->prefix . "bpvm_summary"; // daily summary.

    $sql = "CREATE TABLE $bpvm_voting_data_table (
                            ID int(11) NOT NULL AUTO_INCREMENT,
                            postid bigint(20) NOT NULL,
                            post_type varchar(200) NOT NULL,
                            vote_type int(20) DEFAULT 1,
                            votes bigint(20) DEFAULT 1,
                            vote_date datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
                            voted_ip VARCHAR(24) NOT NULL, 
                            user_id INT NOT NULL DEFAULT '0',
                            PRIMARY KEY  (ID)
                    );
                    CREATE TABLE $bpvm_voting_summary_table (
                            ID bigint(20) NOT NULL AUTO_INCREMENT,
                            postid bigint(20) NOT NULL,
                            post_type varchar(200) NOT NULL,
                            vote_type int(20) DEFAULT 1,
                            vote_date date NOT NULL DEFAULT '0000-00-00',
                            total_votes bigint(20) NOT NULL DEFAULT 1,
                            last_voted datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
                            PRIMARY KEY  (ID)
                    );";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
  }
}

new BpvmDbSettings();
