<?php

/*
 * @Description: Append/prepend a voting box with the single post/page/custom post type content.
 *  */

/**
 * @param string $postId
 * 
 * @return [int]
 */
function bpvmGetTheParentCategoryId($postId = "")
{

    $categories = get_the_category($postId);

    // Initialize a variable to store the first category
    $catInfo = [];

    // Check if there are categories assigned to the post
    if ($categories) {
        // Retrieve the first category from the categories array
        $catInfo = $categories[0];
    }

    // Output the first category name and link
    if (!empty($catInfo)) {
        // echo '<a href="' . esc_url(get_category_link($first_category->term_id)) . '">' . esc_html($first_category->name) . '</a>';

        return [
            'catId' => $catInfo->term_id,
            'catName' => $catInfo->term_id
        ];
    } else {
        return [];
    }
}

function display_pvm_interface($content)
{

    // Get the current post id.
    $post_id = get_the_ID();

    // Retrive all options from plugin option panel.
    $pvm_data = get_option('bwl_pvm_options');

    // Get single post voting box display status. 
    // @param: 0/null=hide, 1=show, 2=closed, 3=paused, 4=date ranage
    $bwl_pvm_display_status = get_post_meta($post_id, "bwl_pvm_display_status", true);


    $meta_IP = get_post_meta($post_id, "pvm_voted_ip");

    // retrive the status of display current 

    $status = 1;

    if (isset($pvm_data["pvmpt_" . get_post_type($post_id)]) && $pvm_data["pvmpt_" . get_post_type($post_id)] == 0) {

        $status = 0;
    }

    if ($status == 0) {

        return $content;
    }

    /*----- Voting Range Status: Introduced in version  1.0.7 -----*/

    // Check Date Status In here.

    $bpvm_vote_start_date = get_post_meta($post_id, "bpvm_vote_start_date", true);
    $bpvm_vote_end_date = get_post_meta($post_id, "bpvm_vote_end_date", true);
    $bpvm_current_date =  date("m") . '/' . date("d") . '/' . date("Y");

    // Voting Interval Issue fixed in version 1.1.0

    if ($bwl_pvm_display_status == 4 && $bpvm_vote_start_date != "" && $bpvm_vote_end_date != "" && $bpvm_current_date >= $bpvm_vote_start_date && $bpvm_current_date <= $bpvm_vote_end_date) {
        // Voting Date Range Set and allowed for voting.
        $bwl_pvm_display_status = 1;
    } else if ($bwl_pvm_display_status == 4 && $bpvm_vote_start_date != "" && $bpvm_vote_end_date != "" && $bpvm_current_date < $bpvm_vote_start_date) {
        // voting time is not started yet.
        $bwl_pvm_display_status = 4;
    } else if ($bwl_pvm_display_status == 4 && $bpvm_vote_start_date != "" && $bpvm_vote_end_date != "" && $bpvm_current_date > $bpvm_vote_end_date) {
        // Voting time has been closed.
        $bwl_pvm_display_status = 5;
    }

    // @Description: Display voting interface in blog lists/category/tag/archive page.
    // @Since: 1.1.4

    $bpvm_display_auto_interface = 0;

    if (isset($pvm_data['bpvm_display_auto_interface']) && $pvm_data['bpvm_display_auto_interface'] == 1) {
        $bpvm_display_auto_interface = 1;
    }


    if (!is_singular(get_post_type($post_id))) {
        // This is an update for modal window request.
        $post_id = isset($_REQUEST['id']) ? $_REQUEST['id'] : $post_id;
        return ($bpvm_display_auto_interface == 1) ? $content . do_shortcode("[bwl_pvm id='" . $post_id . "' status='" . $bwl_pvm_display_status . "' /]") : $content;
    }

    // Get the voting box display location. 
    // @param: 1/null=After post (default), 2=before post
    $bwl_pvm_display_location = get_post_meta($post_id, "bwl_pvm_display_location", true);
    // var_dump($bwl_pvm_display_location);

    //@Description: Display final content with voting box.
    //@Since: 1.0.0

    if (isset($bwl_pvm_display_location) && $bwl_pvm_display_location == 2) {
        $content = do_shortcode('[bwl_pvm status=' . $bwl_pvm_display_status . ' /]') . $content;
    } else {
        $content .= do_shortcode('[bwl_pvm status=' . $bwl_pvm_display_status . ' /]');
    }

    return $content;
}

add_filter('the_content', 'display_pvm_interface');
